SystemOrganization addCategory: #ConfigurationOfSightCoverage!

Object subclass: #ConfigurationOfSightCoverage
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSightCoverage'!

!ConfigurationOfSightCoverage class methodsFor: 'private' stamp: 'mt 1/31/2012 15:57:20.48'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfSightCoverage class methodsFor: 'private' stamp: 'mt 1/31/2012 15:57:20.487'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
					"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfSightCoverage class methodsFor: 'metacello tool support' stamp: 'mt 1/31/2012 15:57:20.498'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSightCoverage class methodsFor: 'metacello tool support' stamp: 'mt 1/31/2012 15:57:20.505'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfSightCoverage class methodsFor: 'loading' stamp: 'mt 1/31/2012 15:58:00.969'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfSightCoverage class methodsFor: 'loading' stamp: 'mt 1/31/2012 15:57:20.525'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfSightCoverage class methodsFor: 'loading' stamp: 'mt 1/31/2012 15:57:20.533'!
loadSnapshot
	"Load the latest snapshot which may be buggy but is not equivalent with the current head #development version."

	"self loadSnapshot"

	<apiDocumentation>
	^(self project version: #snapshot) load! !

!ConfigurationOfSightCoverage class methodsFor: 'metacello tool support' stamp: 'mt 1/31/2012 15:57:20.512'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfSightCoverage class methodsFor: 'accessing' stamp: 'mt 1/31/2012 15:57:20.54'!
project

	^self new project! !

!ConfigurationOfSightCoverage class methodsFor: 'unloading Metacello' stamp: 'mt 1/31/2012 15:57:20.546'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfSightCoverage methodsFor: 'baselines' stamp: 'mt 1/31/2012 16:03:57.427'!
baseline100: spec 
	<version: '1.0-baseline'>
        
	spec for: #common do: [
      	spec blessing: #baseline.
      	spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/CodeSight'. 
					
		spec project: 'SwaUtil' with: [
			spec
				className: 'ConfigurationOfSwaUtil';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec
			package: 'MethodWrappers' with: [spec
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'];
			package: 'ProcessSpecific' with: [spec
				repository: 'http://www.squeaksource.com/ProcessLocalStorage'].
								
		spec 
			package: 'Sight-Coverage' with: [ 
				spec requires: #( 'SwaUtil' 'ProcessSpecific' 'Sight-Tracing' ) ];
			package: 'Sight-Tracing' with: [
				spec requires: #( 'MethodWrappers' 'SwaUtil' 'Sight-TestBed' )];
			package: 'Sight-TestBed'.
		
		spec
			group: 'default' with: #('Sight-Coverage')].! !

!ConfigurationOfSightCoverage methodsFor: 'baselines' stamp: 'mt 2/21/2013 17:49:16.054'!
baseline101: spec 
	<version: '1.0.1-baseline'>
        
	spec for: #common do: [
      	spec blessing: #baseline.
      	spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/CodeSight'. 
					
		spec project: 'SwaUtil' with: [
			spec
				className: 'ConfigurationOfSwaUtil';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec
			package: 'MethodWrappers' with: [spec
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'].
								
		spec 
			package: 'Sight-Coverage' with: [ 
				spec requires: #( 'SwaUtil' 'Sight-Tracing' ) ];
			package: 'Sight-Tracing' with: [
				spec requires: #( 'MethodWrappers' 'SwaUtil' 'Sight-TestBed' )];
			package: 'Sight-TestBed'.
		
		spec
			group: 'default' with: #('Sight-Coverage')].! !

!ConfigurationOfSightCoverage methodsFor: 'symbolic versions' stamp: 'mt 2/22/2013 15:19:03.311'!
development: spec
	<symbolicVersion: #development>
	
	spec for: #'common' version: '1.1.0'.! !

!ConfigurationOfSightCoverage methodsFor: 'accessing' stamp: 'mt 1/31/2012 15:57:20.428'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfSightCoverage methodsFor: 'symbolic versions' stamp: 'mt 2/22/2013 15:19:07.197'!
snapshot: spec
	<symbolicVersion: #snapshot>
	
	spec for: #'common' version: '1.0.6'.! !

!ConfigurationOfSightCoverage methodsFor: 'symbolic versions' stamp: 'mt 2/22/2013 15:19:10.317'!
stable: spec 
	<symbolicVersion: #stable>
	
	spec for: #'squeak4.x' version: '1.0.6'.! !

!ConfigurationOfSightCoverage methodsFor: 'versions' stamp: 'mt 2/7/2012 13:34:46.215'!
version100: spec 
	<version: '1.0' imports: #('1.0-baseline') >
        
	spec for: #common do: [
		spec blessing: #release.
		spec author: 'Marcel Taeumel'.
		
		spec
			project: 'SwaUtil' with: '1.1.2';
			package: 'MethodWrappers' with: 'MethodWrappers-mt.20';
			package: 'ProcessSpecific' with: 'ProcessSpecific-bs.3';
			package: 'Sight-Tracing' with: 'Sight-Tracing-mt.30';
			package: 'Sight-TestBed' with: 'Sight-TestBed-bs.17';
			package: 'Sight-Coverage' with: 'Sight-Coverage-mt.4'].! !

!ConfigurationOfSightCoverage methodsFor: 'versions' stamp: 'mt 2/9/2012 22:49:00.811'!
version101: spec 
	<version: '1.0.1' imports: #('1.0-baseline') >
        
	spec for: #common do: [
		spec blessing: #release.
		spec author: 'Marcel Taeumel'.
		spec description: 'performance improvement'.
		
		spec
			project: 'SwaUtil' with: '1.1.2';
			package: 'MethodWrappers' with: 'MethodWrappers-mt.20';
			package: 'ProcessSpecific' with: 'ProcessSpecific-bs.3';
			package: 'Sight-Tracing' with: 'Sight-Tracing-mt.30';
			package: 'Sight-TestBed' with: 'Sight-TestBed-bs.17';
			package: 'Sight-Coverage' with: 'Sight-Coverage-mt.5'].! !

!ConfigurationOfSightCoverage methodsFor: 'versions' stamp: 'mt 2/27/2012 17:42:41.092'!
version102: spec 
	<version: '1.0.2' imports: #('1.0-baseline') >
        
	spec for: #common do: [
		spec blessing: #release.
		spec author: 'Marcel Taeumel'.
		spec description: 'bugfix version'.
		
		spec
			project: 'SwaUtil' with: '1.1.2';
			package: 'MethodWrappers' with: 'MethodWrappers-mt.20';
			package: 'ProcessSpecific' with: 'ProcessSpecific-bs.3';
			package: 'Sight-Tracing' with: 'Sight-Tracing-mt.31';
			package: 'Sight-TestBed' with: 'Sight-TestBed-bs.17';
			package: 'Sight-Coverage' with: 'Sight-Coverage-mt.7'].! !

!ConfigurationOfSightCoverage methodsFor: 'versions' stamp: 'mt 5/2/2012 14:43:05.107'!
version103: spec 
	<version: '1.0.3' imports: #('1.0-baseline') >
        
	spec for: #common do: [
		spec blessing: #release.
		spec author: 'Marcel Taeumel'.
		spec description: 'bugfix version'.
		
		spec
			project: 'SwaUtil' with: '1.1.3';
			package: 'MethodWrappers' with: 'MethodWrappers-tfel.21';
			package: 'ProcessSpecific' with: 'ProcessSpecific-bs.3';
			package: 'Sight-Tracing' with: 'Sight-Tracing-mt.31';
			package: 'Sight-TestBed' with: 'Sight-TestBed-bs.17';
			package: 'Sight-Coverage' with: 'Sight-Coverage-mt.8'].! !

!ConfigurationOfSightCoverage methodsFor: 'versions' stamp: 'mt 8/20/2012 18:36'!
version104: spec 
	<version: '1.0.4' imports: #('1.0-baseline') >
        
	spec for: #common do: [
		spec blessing: #release.
		spec author: 'Marcel Taeumel'.
		spec description: 'bugfix version'.
		
		spec
			project: 'SwaUtil' with: '1.1.3';
			package: 'MethodWrappers' with: 'MethodWrappers-mt.22';
			package: 'ProcessSpecific' with: 'ProcessSpecific-bs.3';
			package: 'Sight-Tracing' with: 'Sight-Tracing-mt.31';
			package: 'Sight-TestBed' with: 'Sight-TestBed-bs.17';
			package: 'Sight-Coverage' with: 'Sight-Coverage-mt.8'].! !

!ConfigurationOfSightCoverage methodsFor: 'versions' stamp: 'mt 2/22/2013 15:13:59.681'!
version105: spec 
	<version: '1.0.5' imports: #('1.0.1-baseline') >
        
	spec for: #common do: [
		spec blessing: #release.
		spec author: 'Marcel Taeumel'.
		spec description: 'Version for Squeak 4.4'.
		
		spec
			project: 'SwaUtil' with: '1.1.3';
			package: 'MethodWrappers' with: 'MethodWrappers-mt.22';
			package: 'Sight-Tracing' with: 'Sight-Tracing-mt.31';
			package: 'Sight-TestBed' with: 'Sight-TestBed-bs.17';
			package: 'Sight-Coverage' with: 'Sight-Coverage-mt.8'].! !

!ConfigurationOfSightCoverage methodsFor: 'versions' stamp: 'mt 2/22/2013 15:18:39.042'!
version106: spec 
	<version: '1.0.6' imports: #('1.0.1-baseline') >
        
	spec for: #common do: [
		spec blessing: #release.
		spec author: 'Marcel Taeumel'.
		spec description: 'updated method wrappers'.
		
		spec
			project: 'SwaUtil' with: '1.1.3';
			package: 'MethodWrappers' with: 'MethodWrappers-mt.22';
			package: 'Sight-Tracing' with: 'Sight-Tracing-mt.31';
			package: 'Sight-TestBed' with: 'Sight-TestBed-bs.17';
			package: 'Sight-Coverage' with: 'Sight-Coverage-mt.8'].! !

!ConfigurationOfSightCoverage methodsFor: 'versions' stamp: 'mt 2/22/2013 15:18:48.646'!
version110: spec 
	<version: '1.1.0' imports: #('1.0.1-baseline') >
        
	spec for: #common do: [
		spec blessing: #development.
		spec author: 'Marcel Taeumel'.
		
		spec
			project: 'SwaUtil' with: #development.
"			package: 'MethodWrappers' with: 'MethodWrappers-tfel.21';
			package: 'Sight-Tracing' with: 'Sight-Tracing-mt.31';
			package: 'Sight-TestBed' with: 'Sight-TestBed-bs.17';
			package: 'Sight-Coverage' with: 'Sight-Coverage-mt.8'"].! !
